tdl.event.KeyDown

Package tdl :: Module event :: Class KeyDown |
[frames] | no frames]

# Class KeyDown

source code

    object --+
             |
         Event --+
                 |
          KeyEvent --+
                     |
                    KeyDown

Fired when the user presses a key on the keyboard or a key repeats.

Instance Methods
__init__(self, key, char, lalt, lctrl, ralt, rctrl, shift) x.__init__(...) initializes x; see help(type(x)) for signature (Inherited from tdl.event.KeyEvent) | source code
__repr__(self) List an events public attributes when printed. (Inherited from tdl.event.Event) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| type = ``'``KEYDOWN``'`` String constant representing the type of event.

Instance Variables
boolean | alt True if alt was held down during this event. (Inherited from tdl.event.KeyEvent)
string | char A single character string of the letter or symbol pressed. (Inherited from tdl.event.KeyEvent)
boolean | control True if control was held down during this event. (Inherited from tdl.event.KeyEvent)
string | key Human readable names of the key pressed. (Inherited from tdl.event.KeyEvent)
| keychar Similar to key but returns a case sensitive letter or symbol instead of 'CHAR'. (Inherited from tdl.event.KeyEvent)
boolean | leftAlt (Inherited from tdl.event.KeyEvent)
boolean | leftCtrl (Inherited from tdl.event.KeyEvent)
boolean | rightAlt (Inherited from tdl.event.KeyEvent)
boolean | rightCtrl (Inherited from tdl.event.KeyEvent)
boolean | shift True if shift was held down during this event. (Inherited from tdl.event.KeyEvent)

Properties
Inherited from `object`: `__class__`